;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Loading this file installs CG/JS.
;; Please see readme.txt for more information
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(in-package :user)

(eval-when (compile eval load)
  (require :shell)
  (use-package :excl.shell))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; validate files

(let ((platform-file
       (directory
	(merge-pathnames
	 "PLATFORM-*"
	 (path-pathname *load-pathname*)))))
  (or platform-file
      (error "Could not find the PLATFORM file."))
  
  (when (> (length platform-file) 1)
    (error "There is more than one PLATFORM file: ~a." platform-file))
  (setq platform-file (car platform-file))
  
  (or (=~ "^PLATFORM-(.*)" (file-namestring platform-file))
      (error "Cannot parse the PLATFORM file."))
  
  (let ((expected-platform $1)
	(current-platform
	 (format nil "~a~a" (symbol-name sys::.os.) #+smp "smp" #-smp "")))
    (or (string-equal expected-platform current-platform)
	(error
	 "The current platform (~a) does not match the downloaded version (~a)."
	 current-platform expected-platform)))
  ;; We are on the correct platform, fall through...
  )

;; HTML files needed for the operation of CG/JS
;; (this variable's value is generated by build_cgjs.sh)
(defvar *html-files* '("cgjs.html" "ssl-not-found.html" "browser-not-supported.html" ))

(defvar *extra-files*)
(setq *extra-files* nil)

(dolist (file *html-files*)
  (setq file (merge-pathnames file *load-pathname*))
  (or (probe-file file)
      (error "~a does not exist." file))
  (push file *extra-files*))
;; All *html-files* exist...

;; These two are directories but the pathname is specified as
;; a file, so merging works below.
(defvar *cg2js-directory* (merge-pathnames "code.cg2js" *load-pathname*))
(defvar *idejs-directory* (merge-pathnames "code.idejs" *load-pathname*))

(dolist (d (list *cg2js-directory* *idejs-directory*))
  (or (probe-file d)
      (error "~a does not exist." d)))

;; MD5 checksums of the incoming files
;; (this variable's value is generated by build_cgjs.sh)
(defvar *checksums* 
'(
(#xb3374027635467d358cc601db3c8df3b . "./code.cg2js/cg-scroll-bar-mixin.fasl")
(#x3399bdc7d8ead89e3541768e31039f1f . "./code.cg2js/cg-gesture-emulation.fasl")
(#x3a34366bc8bad581119296596f401594 . "./code.cg2js/cg-grid-widget.fasl")
(#x74953aefe3ab7320f63f474ceee18c0a . "./code.cg2js/cg-utility-dialog.fasl")
(#x673a1afa755efa84ba77515358c69aff . "./code.cg2js/cg-wrap-string.fasl")
(#xf7b44e22779da09522bddcf326f4a175 . "./code.cg2js/cg-editable-text.fasl")
(#x8becf6817225d28d9b7f0951b69f75f1 . "./code.cg2js/cg-base.fasl")
(#x577292df283d98946047aeaa48e354fa . "./code.cg2js/cg-lisp-text.fasl")
(#x10cfbef6aeb6e5fd41a559dbff891f24 . "./code.cg2js/cg-intersect.fasl")
(#x1c2dd320de6abe5c979de5b7869f34e9 . "./code.cg2js/cg-choose-printer.fasl")
(#x0f7ac222f15199f8cbb338bcacbba1b1 . "./code.cg2js/cg-multi-line-lisp-text.fasl")
(#x24c384d1e19dab1ee6bab7eb23b374c7 . "./code.cg2js/cg-outline-drag-and-drop.fasl")
(#xaed2f73c17a05c9a60010bf7b00bbe14 . "./code.cg2js/cg-font-dialog.fasl")
(#x3983939d14201112a36bd1822d1fc53e . "./code.cg2js/cg-comtab.fasl")
(#x61ce01b75c12022786cdb3ed1a6221d4 . "./code.cg2js/cg-tooltip.fasl")
(#x82539710382b98d4073c072d6da0254a . "./code.cg2js/cg-chart-or-plot.fasl")
(#x25e666da9ce12f9721bcbd2c0a5d9ce1 . "./code.cg2js/cg-get-pixmap.fasl")
(#x9579c13830733a58c8ea309c36954f71 . "./code.cg2js/cg-status-bar.fasl")
(#xe606ed3f8222d73d931816ba4040d24a . "./code.cg2js/cg-tab-control.fasl")
(#x0cef5933b1beb003c635464fa13a28a2 . "./code.cg2js/cg-icon-pixmap.fasl")
(#xb42da24028475cb55406289f62124411 . "./code.cg2js/cg-list-view.fasl")
(#xb1876e6539c923805db8ed6b01a28462 . "./code.cg2js/cg-text-edit-pane-file-io.fasl")
(#xdd12dfcf6d870aadb679e32633b8871f . "./code.cg2js/cg-rich-edit-pane-clipboard.fasl")
(#xcf7ac1aebae7ae6451f8a1992d6848da . "./code.cg2js/cg-scrolling-static-text.fasl")
(#xf559d0113ac61825e7ddbb2ff92cdccf . "./code.cg2js/cg-project-window.fasl")
(#xcff243abffef72b37f5e24da7ec7ae5d . "./code.cg2js/cg-multi-picture-button-drag-and-drop.fasl")
(#xe83f9ea0286edbbf441fef8f317b1410 . "./code.cg2js/cg-drag-and-drop.fasl")
(#x3c5ba22351d29c2e56f059d7e39d987d . "./code.cg2js/cg-scaling-stream.fasl")
(#xdbed38771791f9e9ccbab1a4132c08e5 . "./code.cg2js/cg-rich-edit-pane.fasl")
(#x951461610f66d3705fd499dc296ef20e . "./code.cg2js/cg-bitmap-stream.fasl")
(#x0d2cb1ddd3cfcadcb988d05d77a8479a . "./code.cg2js/cg-menu.fasl")
(#xe21f056a4ef29151326c008b15470538 . "./code.cg2js/cg-lisp-edit-pane.fasl")
(#x61db1f12d6d285b4785b08e9d7df7281 . "./code.cg2js/cg-intersect-posbox.fasl")
(#xa4b862ac966d612d8fe6a5c6f668bc3e . "./code.cg2js/cg-split-bar.fasl")
(#x4d0ee51c267e2ec0274074ff1c2650d3 . "./code.cg2js/cg-drag-and-drop-image.fasl")
(#x086e6cade48e227f945a7c3fd86977d0 . "./code.cg2js/cg-timer.fasl")
(#x016e877a320944f59f7a80e9d61de42e . "./code.cg2js/cg-text-or-combo.fasl")
(#x7ff03f0fd4d47649dcce26e7f988ff26 . "./code.cg2js/cg-picture-widget-palette.fasl")
(#x63924bca3358c3400f6fdfb78d44d8ae . "./code.cg2js/cg-string-dialog.fasl")
(#x8842dc935c1d4a7670a5134a304ff5e0 . "./code.cg2js/cg-clipboard-pixmap.fasl")
(#xa35324b82d6ba6685ba30853e9c70b3c . "./code.cg2js/cg-menu-tooltip.fasl")
(#xf5bec9f1541a16acab6a6fd86938d220 . "./code.cg2js/cg-outline.fasl")
(#x6a2317621835e804df0ec64420c80e35 . "./code.cg2js/cg-lettered-menu.fasl")
(#xa5adb97d199f8b9262fc61d9c1ead199 . "./code.cg2js/cg-graphics-context.fasl")
(#xfd11cf1a7e6769d8f97ff465fe67f6b5 . "./code.cg2js/cg-item-list.fasl")
(#x9c00b339cd67c25880962ca33f8dccb2 . "./code.cg2js/cg-caret.fasl")
(#xc9f60e95c18e395f8e49eb8f3eb94fd0 . "./code.cg2js/cg-printing.fasl")
(#x13ae654605d225e117c2036f19bd8f97 . "./code.cg2js/cg-pixmap-printing.fasl")
(#x77a630add17e1af6f39ba70ffd0d615c . "./code.cg2js/cg-progress-indicator.fasl")
(#x6105b30cd1d34f8752d7c987bdee4cd4 . "./code.cg2js/cg-dde-utils.fasl")
(#x8f60dffcb574a4384819f1edadfd2f57 . "./code.cg2js/cg-plot-widget.fasl")
(#x101de79cf18a35cced1332aa7acb196b . "./code.cg2js/cg-os-window.fasl")
(#xd21c841a9de6177bb23038e8dad630b4 . "./code.cg2js/cg-calendar.fasl")
(#xd8243d598a2b743d9568412cc1a0cb1e . "./code.cg2js/cg-chart-widget.fasl")
(#x623dbef2b8881be3c88143b319375eab . "./code.cg2js/cg-file-dialog.fasl")
(#xb4d45f8d75320ba4dc54f9a7cb2e210c . "./code.cg2js/cg-nodes.fasl")
(#x2efbf511ef71c46c825b2837cee04046 . "./code.cg2js/cg-lamp.fasl")
(#xb8f57ddd139d4f15f30112e1b8e2b1c3 . "./code.cg2js/cg-html-dialog.fasl")
(#x728a30263262c9eda090934cbfcbedcc . "./code.cg2js/cg-multi-picture-button-tooltip.fasl")
(#x44f77ae97a4b739dcfeb38018f0d5bf8 . "./code.cg2js/cg-class-slot-grid.fasl")
(#xf6fb88bbaa8904f0106f7c4b9685cd7d . "./code.cg2js/cg-choice-list.fasl")
(#x4945804219a886296ceb2f7efb90181e . "./code.cg2js/cg-multi-picture-button.fasl")
(#x3f5890b15011f6ce6075c53c0c17bdbf . "./code.cg2js/cg-multi-line-editable-text.fasl")
(#x5a65045cc2941d2dd27e7e6e7fe2c979 . "./code.cg2js/cg-hotspot.fasl")
(#xa1a4ec64bc31b742af0806eedad256cf . "./code.cg2js/cg-property.fasl")
(#xf74801147641f5144fdf44f2b09f8b83 . "./code.cg2js/cg-dropping-outline.fasl")
(#x4a8a72486273f8336fc52160457995ef . "./code.cg2js/cg-template-string.fasl")
(#x686f28f30749f46ff1616b92a057ff29 . "./code.cg2js/cg-palette.fasl")
(#x4751c89947b3963a59d4e9fe75f8196a . "./code.cg2js/cg-selected-object.fasl")
(#x122bbaff3a3cbec6233330a8edf4916e . "./code.cg2js/cg-up-down-control.fasl")
(#xb52fb043da6502b9b781e0162217cc39 . "./code.cg2js/cg-keyboard-shortcuts.fasl")
(#xe0d35384f74f0a2d3a2c582f8b67d0f4 . "./code.cg2js/cg-layout.fasl")
(#xb119ccdcb370c79d4dfdae727c02ab88 . "./code.cg2js/cg-get-position.fasl")
(#xef4c9bdb674fd416f9cdbf651d79a1bf . "./code.cg2js/cg-lisp-widget.fasl")
(#xe49e1e8f464f4f9ff7a847a2db1e6bdb . "./code.cg2js/cg-grid-widget-drag-and-drop.fasl")
(#xbdaa56dc2a53a926c19fd3fb5e67c354 . "./code.cg2js/cg-object-editor.fasl")
(#xb1ea0646ee4712ba8e49d2f9e10d9b43 . "./code.cg2js/cg-class-grid.fasl")
(#x29472d300a39202fda7d057d122cdd5b . "./code.cg2js/cg-yes-no-string.fasl")
(#xe9e7784671942a7a3b0507ec4d32b7c6 . "./code.cg2js/cg-toggling-widget.fasl")
(#x960a4d763c2f00ee84b84da08b38eee1 . "./code.cg2js/cg-text-edit-pane-mark.fasl")
(#x634d71785fe7d732fedf2ebe3bdc479e . "./code.cg2js/cg-button.fasl")
(#x5cdf2681695ff04e830ccff0f2263bc0 . "./code.cg2js/cg-object-editor-layout.fasl")
(#x84ae57bb6398ded47b6b843f62f93f41 . "./code.cg2js/cg-scroll-bar.fasl")
(#x976c6612703ce4126e9800776dabe768 . "./code.cg2js/cg-combo-box.fasl")
(#x4324d3eadced8436ce37942395dc8463 . "./code.cg2js/cg-web-browser.fasl")
(#x45fb0b5cf073a6f1dcba8d58a121a186 . "./code.cg2js/cg-drawable.fasl")
(#xc6c4fe22cd0b7858d79ecb827f8750f0 . "./code.cg2js/cg-cursor-pixmap.fasl")
(#x00c0a9e88a4213367e2f8162b7ef2c48 . "./code.cg2js/cg-message-dialog.fasl")
(#x6ae3a766ab83478794a02152251a947f . "./code.cg2js/cg-text-widget.fasl")
(#xed386475e962de8ed64543a1ec64b53e . "./code.cg2js/cg-static-text.fasl")
(#x7f355c3c30edcbef3d2202e01c07fffb . "./code.cg2js/cg-class-support.fasl")
(#xd9995414c1e57179049e444ceff1231d . "./code.cg2js/cg.fasl")
(#x2bab179435c92a90e916ec6a2dae2a7e . "./code.cg2js/cg-directory-dialog.fasl")
(#x3a193a6a334e7d5300b0c306c983e8ff . "./code.cg2js/cg-clipboard.fasl")
(#x56c185f780c1132386450695ac5ebe55 . "./code.cg2js/cg-drawable-clipboard.fasl")
(#xc5d798f18d4a73ef631c67cf432dba54 . "./code.cg2js/cg-bitmap-pane.fasl")
(#xa743d74e954cd0c3c9902f65fc303f1d . "./code.cg2js/cg-bitmap-pane-clipboard.fasl")
(#x0dbc898c95e83e6925102aeea269d6cd . "./code.cg2js/cg-check-box.fasl")
(#x252600d12d21bbd3068129985fc386ba . "./code.cg2js/cg-color-dialog.fasl")
(#xbd7e4ea717cbb6bb914023d99aa69260 . "./code.cg2js/cg-text-edit-pane.fasl")
(#x4d201aeb06ddde6547ca71ebaf411e31 . "./code.cg2js/cg-dialog-item.fasl")
(#x0f766487cf88716a3f436bf237f13773 . "./code.cg2js/cg-edit-in-place.fasl")
(#x86064c5c2ff9ecea573f197d44781337 . "./code.cg2js/cg-tray.fasl")
(#xcd90078d73410238bba386387a30b12d . "./code.cg2js/cg-paren-matching.fasl")
(#x6eec81850c89e200c5c6b22bde5cfdce . "./code.cg2js/cg-player.fasl")
(#x9f056f5e7d22919cc971ab270553a755 . "./code.cg2js/cg-yes-no-list.fasl")
(#x224c81b9c61bf330aef132f473f1c475 . "./code.cg2js/cg-common-control.fasl")
(#x2d2a001b699898ccb10ec092917bf5cd . "./code.cg2js/cg-pixmap-file-io.fasl")
(#x793426f4af6d32355b135100bf920b16 . "./code.cg2js/cg-os-widget.fasl")
(#xd04271d8904d3844e2dfc72eb227e5e5 . "./code.cg2js/cg-sample-file-menu.fasl")
(#x36b6a05edd0ea0be5fa1bf86925ac076 . "./code.cg2js/cg-trackbar.fasl")
(#xb2cc63cf7239a51287c1e5f84e1a8388 . "./code.cg2js/cg-rich-edit.fasl")
(#x26fafedc3e56a3938a312592fd85309d . "./code.cg2js/cg-find-string-dialog.fasl")
(#x5009b0acdac83de172a015adeda9ec88 . "./code.cg2js/cg-html-widget.fasl")
(#xb474a33604dc034ed811b44fbd30750e . "./code.cg2js/cg-rich-edit-pane-printing.fasl")
(#x7186f3a760c7132a310c71ce14c00e70 . "./code.cg2js/cg-directory-dialog-os.fasl")
(#xdae9a680b26cff98cd0871b8f7d18b60 . "./code.cg2js/cg-acache.fasl")
(#x6a125f49654522059031b322c19a7cae . "./code.cg2js/cg-shortcut-menu.fasl")
(#x954bf66b16d181612dd6e0bd766266a9 . "./code.cg2js/cg-pixmap-widget.fasl")
(#xb1ec49f364ffd002400d6c01d356c4d7 . "./code.cg2js/cg-icon.fasl")
(#x4f930308155422fa49e8a4955b26f036 . "./code.cg2js/cg-pixmap.fasl")
(#xf317c0655a1e3d41be894f81cd999c11 . "./code.cg2js/cg-clipboard-stack.fasl")
(#x3eb539e2d8638381642812c000b7ce3e . "./code.cg2js/cg-outline-edit-in-place.fasl")
(#xd28a53a3347187d8afb3f0dedef1819c . "./code.cg2js/cg-toolbar.fasl")
(#xe50ad7498fbea47133cc828e9b49eb02 . "./code.cg2js/cg-radio-button.fasl")
(#x27d1f532334a84d68e353f4056202415 . "./code.cg2js/cg-curve.fasl")
(#x994b69ccd31f58a2a2595bcd03dac489 . "./code.cg2js/cg-picture-widget.fasl")
(#xee897b6ab40368ccdbea6f6918273c12 . "./code.cg2js/cg-dev.fasl")
(#x73b1187a86f0a0819f0b7e6894434e00 . "./code.cg2js/cg-group-box.fasl")
(#xf6076ee9c1af975d6b1993a86d1e0f34 . "./code.cg2js/cg-fill-texture.fasl")
(#x0e5476609746332e054f70c69795b924 . "./code.cg2js/cg-pixmap-rotate.fasl")
(#x0895986854d4243b3579adc613b52ea6 . "./code.idejs/ide-keyshort.fasl")
(#x918c8150730273c290b84c30c35e668b . "./code.idejs/ide-form.fasl")
(#x19cbb3c0e1e8e73e5de74dc9b13cc84e . "./code.idejs/ide-find-in-files.fasl")
(#x547ddd579cb450cd9464000dd017d35e . "./code.idejs/ide-class-grapher.fasl")
(#x1da16e521c90752694711c11da3bedff . "./code.idejs/ide-base.fasl")
(#x0c57952af1f94be61787d86cc44dec6e . "./code.idejs/ide-class-browser.fasl")
(#xf93542776f3491c9e3e6864f0fbf42ae . "./code.idejs/ide-find-definitions.fasl")
(#x5b8ea40929b85e1e03a1c91751efa9f7 . "./code.idejs/ide-package-list.fasl")
(#x16d1dd8fb5e1a1e333c6b74505a15585 . "./code.idejs/ide-grapher.fasl")
(#xe63d2c120633e5d8377c8929886212c5 . "./code.idejs/ide-dev.fasl")
(#xd0df5c11f98048515d23baa5b0d92f40 . "./code.idejs/ide.fasl")
(#x3e2ec0d480a6701be55c363c2c534018 . "./code.idejs/ide-trace.fasl")
(#xac2939f28223830cdebfc5718d4099d8 . "./code.idejs/ide-apropos.fasl")
(#x15cbf5ffe5cdd4bd05c00164506aa63d . "./code.idejs/ide-inspector.fasl")
(#x8e86e6cd86032a7609d6dcc6095fdc99 . "./code.idejs/ide-acache.fasl")
(#x3795c06820eb78c772f7eed62e16441c . "./code.idejs/ide-project.fasl")
(#x027dc746a6ae7cbe7b15d407525b6ce3 . "./code.idejs/ide-window-list.fasl")
(#xf8ca60deb00b52de7a57007f48cefc33 . "./code.idejs/ide-intro.fasl")
(#xfe045ef1cb6ff36f30095da2f0301261 . "./code.idejs/ide-clipboard.fasl")
(#x323582397ce50106a1283e690f802dd1 . "./code.idejs/ide-editor.fasl")
(#x561d4c03824b3c85ed4975b593de7f6f . "./code.idejs/ide-process-browser.fasl")
(#xbcc737252c7bfc58b6bb9daddf8c939c . "./code.idejs/ide-patch-dialog.fasl")
(#x35c78d055c6e6905538431bf35248f9e . "./code.idejs/ide-navigator.fasl")
(#x4469068b47e063cb9811630bd05af4c2 . "./cgjs.html")
(#xdac1739373835d1a63cbafa2c3e0b06a . "./ssl-not-found.html")
(#x90c6d2a65504d45266ad9fa3a49be2f9 . "./browser-not-supported.html"))
 )

(let ((files-ok
       (dolist (checksum *checksums* t)
	 (when (/= (car checksum)
		   (md5-file
		    (merge-pathnames (cdr checksum) *load-pathname*)))
	   (return nil)))))
  (cond
   ((not files-ok)
    (error "The extracted files failed the checksum test.  ~
Please download and/or extract again."))
   (t
    (format t "Checksums on files are OK...~%"))))

;; We have validated all the files are there...

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; check for needed patches

(eval-when (compile eval load) (require :build))

(defvar *required-patches* '(#+macosx ("build" . 3)))

(dolist (required-patch *required-patches*)
  (let ((existing-patch (assoc (car required-patch)
			    (cdr (assoc :system sys::*patches*))
			    :test #'string=)))
    (when (null existing-patch)
      (error "Could not find patch info for the ~s module."
	     (car required-patch)))
    (when (not (>= (second existing-patch) (cdr required-patch)))
      ;; The build patch number is NOT >= to the one we require
      (error "~
Expected version ~d of ~s but have version ~d.  Please update ~
your lisp with update.~a and then do the CG/JS installation again."
	     (cdr required-patch) (car required-patch)
	     (second existing-patch)
	     #+mswindows "exe"
	     #-mswindows "sh"))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; copy files

(defun copy (source dest)
  (cond
   ((file-directory-p source)
    (format t "Copy directory ~a~%" (enough-namestring source))
    (copy-directory source dest :quiet t))
   (t
    (format t "Copy file ~a~%" (enough-namestring source))
    (sys:copy-file source dest :verbose nil))))

(defvar *sys* (translate-logical-pathname (pathname "sys:")))

(cond
 ((excl::pathname-equalp (truename *sys*)
			 (path-pathname *load-truename*))
  (format t "Files are already in place, no copying requiring.~%"))
 (t ;; copy files, replacing them with new ones if they already exist
  (let (dest)
    (dolist (from *extra-files*)
      (setq dest (merge-pathnames (file-namestring from) *sys*))
      (when (probe-file dest) (delete-file dest))
      (copy from dest))
    
    (dolist (from (list *cg2js-directory* *idejs-directory*))
      (setq dest (merge-pathnames (file-namestring from) *sys*))
      ;; now make it a directory pathname
      (setq dest (pathname-as-directory dest))

      (when (probe-file dest) (delete-directory-and-files dest))
      (copy (pathname-as-directory from) dest)))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; update develenv.cl to load CG/JS before the original version of CG

(defvar *setup-cgjs-loading* "sys:setup-cgjs-loading.cl")

;; Because users might use an ANSI lisp to install, have to make sure
;; the resulting file can be loaded into an ANSI and Modern lisp.
(with-open-file (s *setup-cgjs-loading* :direction :output
		 :if-exists :supersede)
  (format s "~
;; This file was created by install-cgjs.cl.
;; Please do not edit it.

")
  (dolist (dir (list "code.cg2js" "code.idejs"))
    (format s "
(let ((path (make-pathname
             :host \"sys\"
             :directory '(:relative \"~a\")
	     :type \"fasl\"
	     )))
  (format t \";; *require-search-list*: adding: ~~s~%\" path)
  (push path sys:*require-search-list*))

"
	    dir)))

(defvar *develenv.cl* (pathname "sys:develenv.cl"))

(when (not (probe-file *develenv.cl*))
  (setf (file-contents *develenv.cl*)
    ";; This file is loaded before images are rebuilt with update.sh/update.exe

"))

(let ((contents (file-contents *develenv.cl*)))
  (cond
   ((match-re
     (format nil "^#\\|\\|# \\(load \"sys:~a"
	     (file-namestring *setup-cgjs-loading*))
     contents
     :multiple-lines t)
    (format t "develenv.cl already correctly loads CG/JS.~%"))
   ((match-re
     (format nil "^#\\+ignore \\(load \"sys:~a"
	     (file-namestring *setup-cgjs-loading*))
     contents
     :multiple-lines t)
    (format t "develenv.cl: CG/JS disabled; will enable.~%")
    (setf (file-contents *develenv.cl*)
      (replace-re  contents
		  (format nil "^#\\+ignore *\\(load \"sys:~a"
			  (file-namestring *setup-cgjs-loading*))
		  (format nil "#||# (load \"sys:~a"
			  (file-namestring *setup-cgjs-loading*))
		  :multiple-lines t
		  :count 1)))
   (t
    (format t "develenv.cl: adding CG/JS initialization.~%")
    (setf (file-contents *develenv.cl*)
      (concatenate 'simple-string
	contents
	(format nil "~

;; To disable the use of CG/JS and go back to the originally released
;; (and possibly patched) version of CG/IDE, change the #||# to
;; #+ignore on the following line and the rebuild images by running
;; update.sh or update.exe, depending on your platform:
#||# (load \"sys:~a\")~%~%"
		(file-namestring *setup-cgjs-loading*)))))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; success!

(let ((msg (format nil "~
CG/JS installation successful!

NOTE: to use CG/JS you must rebuild images by running 'update.~a'
      in the Allegro CL directory (~a)."
		   #+mswindows "exe"
		   #-mswindows "sh"
		   *sys*)))
  #-mswindows (format t "~&~%~a~%" msg)
  #+mswindows (excl::internal-message-box msg "CG/JS Installation" :type :ok))
